"""Prebuild config settings for several Large Language Models and providers"""

# AUTOGENERATED! DO NOT EDIT! File to edit: ../../nbs/96_gradio_preconfigs.ipynb.

# %% auto 0
__all__ = []

# %% ../../nbs/96_gradio_preconfigs.ipynb 4
from .config import *
